.. CasADi documentation master file, created by
   sphinx-quickstart on Mon May 28 22:05:33 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: defs.rst

Welcome to CasADi's documentation!
==================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :numbered:

   intro
   install
   symbolic
   function
   ccode
   custom
   daebuilder
   ocp
   opti
   usage
